@@ -3,7 +3,7 @@ package Word::Rhymes;
 use strict;
 use warnings;
 
-our $VERSION = '1.02';
+our $VERSION = '1.03';
 
 use Carp qw(croak);
 use HTTP::Request;
@@ -20,6 +20,8 @@ use constant {
     MAX_SYLLABLES       => 100,
     MULTI_WORD          => 0,
     RETURN_RAW          => 0,
+    MIN_LIMIT           => 1,
+    MAX_LIMIT           => 1000,
 
     # print() related
     MAX_NUM_COLS        => 8,
@@ -107,6 +109,25 @@ sub file {
 
     return $self->{file} // '';
 }
+sub limit {
+    my ($self, $limit) = @_;
+
+    if (defined $limit) {
+        croak("limit must be an integer") if $limit !~ /^\d+$/;
+        if ($limit < MIN_LIMIT || $limit > MAX_LIMIT) {
+            croak(
+                sprintf(
+                    "limit must be between %d and %d",
+                    MIN_LIMIT,
+                    MAX_LIMIT
+                )
+            );
+        }
+        $self->{limit} = $limit;
+    }
+
+    return $self->{limit} // MAX_LIMIT;
+}
 sub max_results {
     my ($self, $max) = @_;
 
@@ -241,6 +262,9 @@ sub _args {
     # file
     $self->file($args->{file}) if exists $args->{file};
 
+    # limit
+    $self->limit($args->{limit}) if exists $args->{limit};
+
     # max_results
     $self->max_results($args->{max_results}) if exists $args->{max_results};
 
@@ -296,6 +320,14 @@ sub _process {
             @{ $organized{$_} } = sort {$a->{score} <=> $b->{score}} @{ $organized{$_} };
         }
     }
+
+    # Limit the result count in each syllable href
+
+    for (keys %organized) {
+        next if scalar @{ $organized{$_} } <= $self->limit;
+        @{ $organized{$_} } = @{ $organized{$_} }[0..$self->limit -1];
+    }
+
     return \%organized;
 
 }
@@ -331,11 +363,6 @@ __END__
 
 Word::Rhymes - Takes a word and fetches rhyming matches from RhymeZone.com
 
-=for html
-<a href="http://travis-ci.com/stevieb9/word-rhymes"><img src="https://www.travis-ci.com/stevieb9/word-rhymes.svg?branch=master"/></a>
-<a href="https://ci.appveyor.com/project/stevieb9/word-rhymes"><img src="https://ci.appveyor.com/api/projects/status/x1u0nf8bvfg7q3m3?svg=true"/></a>
-<a href='https://coveralls.io/github/stevieb9/word-rhymes?branch=master'><img src='https://coveralls.io/repos/stevieb9/word-rhymes/badge.svg?branch=master&service=github' alt='Coverage Status' /></a>
-
 =head1 DESCRIPTION
 
 Provides the ability to fetch words that rhyme with a word, while allowing for
@@ -480,6 +507,24 @@ I<Default>: Empty string.
 
 I<Returns>: The name of the file if set, empty string otherwise.
 
+=head2 limit
+
+Sets the maximum number of rhyming words to return/display under each number of
+syllables section. This filtering takes place after all other sorting has
+occurred.
+
+I<Parameters>:
+
+    $limit
+
+The maximum number of rhyming words to return per each syllable count section.
+
+I<Valid values>: 1-1000
+
+I<Default>: 1000
+
+I<Returns>: The currently set value.
+
 =head2 max_results
 
 Sets the maximum number of rhyming words to fetch over the Internet.
